////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
// Adapted from main EFC-MORI .do files 2015/3/17
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////

/* 	NOTE: as this is a dataset we collected, we don't need to document the variable derivation in the same way - INSTEAD, we need to 
	make sure the publicly released dataset is comprehensible, with the appropriate variables supplied.  */

use "${EFCMORIdir}\MORI-v1-06.dta", replace			// This is NOT the version with cleaning for the 2014 paper, but the fuller version of the data
// Estfraud is already in the right format - nothing else needs doing

****************************************************
** NEWSPAPER VARIABLES
****************************************************

egen anypapercount = rowtotal(daily1-daily20)
egen keypapercount = rowtotal(daily2 daily3 daily4 daily6 daily8 daily9 daily11 daily12 daily20)
	label var keypapercount "Number of daily papers read, from list of main papers"
gen _paper=.
	replace _paper=0 	if 								anypapercount==0
	replace _paper=99 	if 								keypapercount>=2		// Reading multiple papers - needs a separate code
	replace _paper=1 	if daily8==1 					& keypapercount==1
	replace _paper=2	if daily9==1 					& keypapercount==1
	replace _paper=3	if daily12==1 					& keypapercount==1
	replace _paper=5	if daily11==1 					& keypapercount==1
	replace _paper=7	if daily3==1 					& keypapercount==1
	replace _paper=9	if daily4==1 					& keypapercount==1
	replace _paper=10	if daily2==1 					& keypapercount==1
	replace _paper=10	if daily20==1 					& keypapercount==1
	replace _paper=11	if daily6==1 				 	& keypapercount==1
	replace _paper=12	if (daily10==1 | daily13==1) 	& keypapercount==1
	replace _paper=99	if anypapercount>=1 			& missing(_paper)		
	replace _paper=.d	if daily25==1 					
	

****************************************************
** OTHER VARS / FINAL THINGS
****************************************************

// Renaming to match other datasets
rename wtnew	_weight
rename serial	_uniqueid
rename numage	_age
rename male		_male
rename sgrade	_sgrade
rename week		_week

// Making categorial vars have similar groupings
recode region (1=1)(2=2)(3=3)(4=5)(5=4)(6=7)(7=6)(8=10)(9=13)(10=11)(11=12)(12=14), gen(_region) 	// To match BSA categories (see OneNote)
recode qual (4 5=1)(3=2)(1 2 6=3)(7=4)(8=.s)(9=.d), gen(_quals)
recode work (1 5=1)(2=2)  (6 7=3)(9=4)(8=5)(3 4 10 11=6)(12=.r), gen(_work1)	// To match EFCYouGov, with those working <8hrs/wk treated as not working to match BSA
recode work (1 5=1)(2 3=2)(6 7=3)(9=4)(8=5)(  4 10 11=6)(12=.r), gen(_work2)	// To match EFCYouGov, with those working <8hrs/wk treated as part time workers to match likely self-definition in EFCYouGov
egen _outofwrkben 	= anymatch(benJSA benESA benIS benTCnowrk), values(1)
	replace _outofwrkben = . if missing(benJSA)
egen _irben 		= anymatch(benHB benCTB benCA benTCwork benPC), values(1)
	replace _irben = . if missing(benJSA)
egen _anyben 		= anymatch(_outofwrkben _irben benDLA), values(1)
	replace _anyben = . if missing(benJSA)
recode income (1/5=1)(6/9=2)(10/11=3)(12/15=4)(16=.d)(17=.r), gen(_incquartiles)
	
// Finishing off
keep estfraud _*
compress
aorder
save "${workingdir}\\${filename}_EFCMORI2012", replace
/*
use "${workingdir}\\${filename}_EFCMORI2012", replace
*/
