////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
// NEW DATA CLEANING - dataset not used previously
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////

// Import the dataset they sent over
*usespss using "${RSSMORIdir}\Output_w.sav"		// The USESPSS function corrupts this file for some unknown reason - have gone into SPSS and saved it in Stata, which avoids this problem
use "${RSSMORIdir}\Output_w_exported_from_SPSS.dta", replace	
numlabel _all, add mask(#_)
save "${RSSMORIdir}\Output_w.dta", replace


****************************************************
** CLEANING BENEFIT BELIEFS VARIABLES
****************************************************

// Renaming the relevant variables
rename SD17_* 	spmost*
	egen countspmost	= anycount(spmost1-spmost9), values(1)
	label var countspmost "Number of responses to SPMOST (0=dk)"
rename SD18 	JSAvPen
	label var JSAvPen "Whether govt spends more on JSA or state pensions"
rename SD19		estfraud13
	label var estfraud13 "Estimated fraudulent claims out of every £100, 2013"
	replace estfraud13 = .d if SD19_Codes==99
rename SD20_* 	fraudis*
	forvalues i = 1/9 {
		replace fraudis`i' = .d if fraudis10==1
	/**/ }
rename fraudisSD20_9_other fraudis_text
rename SD22		savemost
	label var savemost "Which policy saves the most money?"
rename SD23		saveleast
	label var saveleast "Which policy saves the least money?"
rename SD26		unemprate3
	label var unemprate3 "Unemployment rate in 2013 (Ipsos MORI)"
	
// Missing variables
forvalues i = 1/9 {
	replace spmost`i'=.d if spmost10==1
/**/ }
mvdecode JSAvPen, mv(4=.d)
mvdecode savemost saveleast, mv(10=.d)
replace unemprate3 = .d if SD26_Codes==99


****************************************************
** CLEANING OTHER BELIEFS VARIABLES
****************************************************

rename	SD05_3_scale1a	oth_age
	replace oth_age = .d if SD05_3_scale1a_Codes==1
rename	SD05_4_scale1a	oth_vote
	replace oth_vote = .d if SD05_4_scale1a_Codes==1
rename	SD31			oth_paper
	replace oth_paper = .d if SD31_Codes==99
rename 	SD32			oth_twitter
	replace oth_twitter = .d if SD32_Codes==99
rename	SD33			oth_facebook
	replace oth_facebook = .d if SD33_Codes==99
rename	SD05_1_scale1a	oth_christian
	replace oth_christian = .d if SD05_1_scale1a_Codes==1
rename 	SD05_2_scale1a	oth_muslim
	replace oth_muslim = .d if SD05_2_scale1a_Codes==1
rename	SD05_5_scale1a	oth_blackasian
	replace oth_blackasian = .d if SD05_5_scale1a_Codes==1
rename 	block2_SD10B	oth_migr
	replace oth_migr = .d if block2_SD10B_Codes==99
rename 	block1_SD10A	oth_migrC
	recode oth_migrC (14=.d)
rename	SD12B			oth_asylum
	replace oth_asylum = .d if SD12B_Codes==99
rename	SD12A			oth_asylumC
	recode oth_asylumC (14=.d)
rename	SD09_2_scale1	oth_asylumrise
	recode oth_asylumrise (1=1)(2=0)(3=.d)
rename	SD27			oth_avgsalary
	replace oth_avgsalary = .d if SD27_Codes==99
rename	SD05_6_scale1a	oth_spar
	replace oth_spar = .d if SD05_6_scale1a_Codes==1
rename	SD07			oth_U16preg
	replace oth_U16preg = .d if SD07_Codes==99
rename	SD08			oth_violcrim
	replace oth_violcrim = .d if SD08_Codes==99
rename 	SD09_1_scale1	oth_violrise
	recode oth_violrise (1=1)(2=0)(3=.d)
rename	SD09_5_scale1	oth_crimfall
	recode oth_crimfall (1=1)(2=0)(3=.d)
// After checking, getting rid of questions that I think seem to have been interpreted wrongly
drop oth_spar oth_avgsalary



****************************************************
** OTHER VARS / FINAL THINGS
****************************************************

// Renaming variables for consistency across surveys
rename Respondent_Serial	_uniqueid
rename weight				_weight
rename resp_age				_age
recode resp_gender (1=1)(2=0), gen(_male)
rename STDSOCIALGRADE		_sgrade
destring _sgrade, replace

// Making categorial vars have similar groupings
recode REGION1 (1=1)(2=2)(3=3)(4=5)(5=4)(6=7)(7=6)(8=10)(9=13)(10=11)(11=12)(12=14), gen(_region) 	// To match BSA categories (see OneNote)
gen _quals = . if missing(IND_EDUCATION)			// Categories are by comparing these codes to published table breakdowns
	replace _quals=1 if IND_EDUCATION=="5A6" | IND_EDUCATION=="5B" 
	replace _quals=2 if IND_EDUCATION=="3A" 
	replace _quals=3 if IND_EDUCATION=="3C1" | IND_EDUCATION=="3C2" 
	replace _quals=4 if IND_EDUCATION=="1"   | IND_EDUCATION=="2A" 
encode INCOME, gen(income)
	recode income (1/3=1 "1_lowest income quartile")(4/5=2)(6/7=3)(8/10=4)(11=.r), gen(_incquartiles)
encode IND_EMPLOY, gen(_work1)
	recode _work1 (1 3=1)(2=2)  (8=3)(7=4)(4=5)(5 6=6)
clonevar _work2 = _work1

// Political vars
gen vintention = CL1a
	replace vintention = CL1b if ~missing(CL1b)
	label values vintention CL1a
recode vintention (1=1)(2=2)(3=3)(6=4)(7=5)(8/9=6), gen(_partyvote)
recode CL2 (22=0)(8=1)(9=2)(13=3)(12=5)(3=7)(4=9)(2 20=10)(6=11)(11 14=12)(1 5 7 10 15=99)(21=.d), gen(_paper)

// Ending
keep spmost* JSAvPen estfraud13 fraudis* savemost saveleast unemprate* oth* _*
compress
aorder
order JSA*, after(_weight)
order oth*, last
save "${workingdir}\\${filename}_RSSMORI2013", replace
/*
	use "${workingdir}\\${filename}_RSSMORI2013", replace
*/
