////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
// NEW DATA CLEANING - dataset not used previously
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////

// Import the dataset they sent over
clear
usespss "${TUCdir}\YouGov - TUC SPSS full - 29.01.13.sav"
numlabel TUC1 TUC2 TUC7 TUC10 TUC11 TUC12 TUC13 TUC15, add mask(#_)


****************************************************
** DATA CLEANING
****************************************************

// Going through the main beliefs block
rename TUC2 unempspend 
	label var unempspend 	"Estimated spending on unemployed as % of total welfare budget"
rename TUC3 fraudspend	
	label var fraudspend 	"Estimated fraudulent claims as % of total welfare budget"
rename TUC4 JSAyr
	label var JSAyr			"Estimated % of JSA claimants who claim for more than a year"
rename TUC6 JSAfamily		
	replace JSAfamily = .o if JSAfamily==699999999
	label var JSAfamily		"Estimated £pw of JSA for unemp couple with 2 kids aged 6-10, exc other benefits (HB, CTB, CB)"
rename TUC5 JSAneeded
	replace JSAneeded = .o if JSAneeded==9999999
	label var JSAneeded		"Estimated £pw needed to live on for unemp couple with 2 kids aged 6-10, exc housing costs"
rename TUC11 mediaview	
	label var mediaview		"Whether media gives accurate information about welfare benefits & people who claim them"

// Combining questions into more useful quantities
gen betteroff = .d 			if TUC7==4
replace betteroff = 0 		if TUC7==3
replace betteroff = TUC8 	if TUC7==1
replace betteroff = -TUC9 	if TUC7==2
	label var betteroff "How much better/worse off if 1 parent took NMW 30hrs/wk job, for unemp couple with 2 kids"
rename TUC7 betteroffC
	label var betteroffC "Whether better/worse off if 1 parent took NMW 30hrs/wk job, for unemp couple with 2 kids"
mvdecode betteroffC, mv(4=.d)
	
// Outliers
replace betteroff = .o if betteroff<-1000
	



****************************************************
** DESERVINGNESS
****************************************************

recode TUC10 (1=1 "1_System has created culture of dependency")(3=2 "2_Neither")(2=3 "3_Most claimants victims of circumstances")(4=.d) ///
	, gen(DdependencyT)

// Other attitudes questions added for van Oorscoht (Leuven) book chapter sensitivity analysis April 2016	
recode TUC1 (1=1 "1_too high")(2/3 =0 "0_about right/not high enough")(4=.d), gen(Pbengen)
recode TUC12 (1/2=1 "1_support limiting rise")(3/5=0 "0_other")(6=.d), gen(Pbenrise)

// Currently ignoring the other attitudes questions
drop TUC*


****************************************************
** OTHER VARS / FINAL THINGS
****************************************************

// Rename vars for consistency across datasets
ren ID					_uniqueid
ren Age					_age
recode gender  (1=1)(2=0), gen(_male)
ren W8					_weight
ren social_grade		_sgrade2

// Making categorial vars have similar groupings
* Doesn't have a good region var - but see code in main dataset that converts to this
ren region	_region2
recode education_level (16 17=1)(3 6 7 11/15=2)(2 4 5 8/10=3)(1 18=4)(19=.d)(20=.r), gen(_quals)
recode work_stat (1=1)(2=2)  (4=3)(5=4)(6=5)(3 7 8=6), gen(_work1)	// To match EFCYouGov, with those working <8hrs/wk treated as not working to match BSA
recode work_stat (1=1)(2 3=2)(4=3)(5=4)(6=5)(  7 8=6), gen(_work2)	// To match EFCYouGov, with those working <8hrs/wk treated as part time workers to match likely self-definition in EFCYouGov
recode gross_household_income (1/3=1)(4/6=2)(7/9=3)(10/15=4)(16=.d)(17=.r), gen(_incquartiles)
recode partyid (2=1)(1=2)(3=3)(7=4)(4 6 8/9=5)(10/11=6)(98 99=.n), gen(_partyid)
recode vote_2010 (2=1)(3=2)(4=3)(10=4)(5/9 11=5)(1 12=6)(98 99=.n), gen(_partyvoted)
recode newspaper_readership (16=0)(1=1)(2=2)(3=3)(5=5)(6=7)(8=9)(9=10)(10=11)(4=12)(7 11/15=99), gen(_paper)

// Ending 
keep unempspend fraudspend JSAyr JSAfamily JSAneeded mediaview betteroff* D* P* _*
compress
aorder
order JSA*, after(_weight)
save "${workingdir}\\${filename}_TUC", replace
/*
	use "${workingdir}\\${filename}_TUC", replace
*/

