////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
// MASTER CLEANING FILE
// Cleaning done when files are merged, rather than separately
// I rarely move this into a separate file - but there was just too much to do here
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////


**************************************
* Merging
**************************************

clear
gen _data = ""
	label var _data "Data source"
local datasets "${datasets}"		// See above for the list
foreach data in `datasets'	{
	append using "${workingdir}\\${filename}_`data'", gen(from`data')
	replace _data = "`data'" if from`data'==1
/**/ }



**************************************
* Things that really should be in the individual files...
**************************************
gen speneither = 1 if spenmost==8 | spennext==8
	replace speneither = .d if missing(speneither) & (spenmost==.d | spennext==.d)
	replace speneither = 0 if speneither==. & ~missing(spenmost)
gen wrkless = .
	replace wrkless = sickdsbN-2 			 if sickdsbN<50
	replace wrkless = 50 					 if sickdsbN==50	
	replace wrkless = wrkless + (uemplwkN-2) if uemplwkN<50
	replace wrkless = wrkless + 50			 if uemplwkN==50
	replace wrkless = .d if sickdsbN==.d | uemplwkN==.d
	replace wrkless = .r if sickdsbN==.r | uemplwkN==.r
	
**************************************
* Further cleaning
**************************************
// Region 
// Step 1: EFCMORI has an odd 'Eastern' category that is different from the others, so I've pooled this here
recode _region (7 10=10)
label define _region 10 "10_SE + Eastern", modify
// Step 2: Make comparable to more aggregated TUC grouping
recode _region2 (3 5=5)			// For the same reason as _region is recoded in the previous lines
label define _region2 1 "1_North" 2 "2_Midlands" 4 "4_London" 5 "5_South and East" 6 "6_Wales" 7 "7_Scotland" 8 "8_NI", modify
label values _region2 _region2
recode _region (1/3=1)(4/5=2)(7=3)(13=4)(6 10=5)(11=6)(12=7)(14=8), gen(Xregion2)
replace _region2 = Xregion2 if missing(_region2)
label var _region2 "Region, grouped (some datasets only have this)"
// Social grade
numlabel social_grade, mask(#_) add
recode _sgrade (1 2=1)(3=2)(4=3)(5 6=4), gen(Xsgrade2)
replace _sgrade2 = Xsgrade2 if missing(_sgrade2)
label var _sgrade2 "Social grade, grouped (some datasets only have this)"
// Political variables
label values _partyvote _partyid
clonevar _partycombined = _partyid
replace _partycombined = _partyvote if _data=="RSSMORI2013" | _data=="MORI2015"
// Country
recode _country (1=2)(2=29)(3=43)(4=19)(5=20)(6=4)(7=7)(8=21)(9=12)(10=16)(11=1)(12=52)(13=11)(14=32)(15=22) ///
	(16=8)(17=57)(18=23)(19=3)(20=15)(21=26)(22=13)(23=30)(24=64)(25=17)(26=28)(27=27)(28=31)(29=69), gen(Xnation)
replace _nation = Xnation if missing(_nation)
label define V6 43 "43_CH" 52 "52_GB" 57 "57_IL (Israel)" 64 "64_RU" 69 "69_UA (Ukraine)", modify		
replace _nation=9 if missing(_nation)
replace _nation=9 if _nation==52
// Survey year
replace _svyyear = 2007 if _data=="EB2007"
replace _svyyear = 2008 if _data=="ESS08"
replace _svyyear = 2009 if _data=="EB2009"
replace _svyyear = 2010 if _data=="Curran2010"
replace _svyyear = 2012 if _data=="EFCMORI2012" | _data=="EFCYouGov2012" | _data=="TUC"
replace _svyyear = 2013 if _data=="RSSMORI2013"
replace _svyyear = 2015 if _data=="MORI2015"


**************************************
* Checks
**************************************
/*
preserve
	keep if _country==12 | missing(_country)
	unab covars: _libauth-_wrkhours
	foreach var in `covars'	{
		capture tab `var'
		if (r(c)==0 | r(c)==.) & r(r)<20 		tab `var' _data  		if _svyyear>=2008 [iweight=_weight], col nof
		else									bysort _data: sum `var' if _svyyear>=2008 [iweight=_weight]
		pause Var is `var'
		/**/ }
restore
END OF CHECKS */


**************************************
* Merging in true figures on a country-by-country basis
**************************************

save "${workingdir}\\${filename}_combined", replace	
clear
insheet using "${dodir}\x. EBmerge unemp true.csv", names
save "${dodir}\x. EBmerge unemp true.dta", replace
use "${workingdir}\\${filename}_combined", replace	
merge m:1 _nation using "${dodir}\x. EBmerge unemp true.dta"
drop _merge countrycode desc
drop if _data==""

* Matching these to the variables they refer to
gen TsickdsbN 			= sick2008
gen TuemplwkN 			= unemp2008
gen Tunemprate2_2007	= unemprate2007
gen Tunemprate2_2009	= unemprate2009
drop sick200? unemp200? unemprate200?



**************************************
* Final tidying and prep for analysis
**************************************
drop X* from* 
drop *onX* caron146 *poor* 		// I'm not interested in their perceptions of whether it's enough to live on - I'm interested in whether they under- or over-estimated the level of benefit
ren unemprate2T unemprate2T_orig
	label var unemprate2T_orig "Correctness in the origindal data, determined by the Eurobarometer research team"
aorder
order JSA*, last
order T*, before(betteroff)
order _data fraudis_text, first
encode _data, gen(_dataset)
	numlabel _dataset, mask(#_) add

* Creating a total of don't knows and refused for each person
unab allvars: _age-JSAyr
mvencode `allvars', mv(.d=-99\.r=-98)
egen numdk	= anycount(`allvars'), values(-99)
	recode numdk (0=0)(1=1)(2/max=2)
egen numref = anycount(`allvars'), values(-98)
	recode numref (0=0)(1/max=1)
mvdecode `allvars', mv(-99=.d\-98=.r)
* Checking the sort of person that refuses answers to income question
capture drop _refusedinc
gen _refusedinc = (_incquartiles==.r) if _incquartiles~=.
	label var _refusedinc "Refused income question"
*	replace _refusedinc = _makeshift if ~missing(_makeshift)		// This was something I improvised from RSS MORI - but want to remove it in case I forget it's there
/*CHECKS
	eststo rESS08_vote: 	logit _refusedinc _male _age i._partyvote [pw=_weight] if _data=="ESS08" & _nation==9
		testparm i(2 3 5 6)._partyvote
	eststo rBSA_vote: 		logit _refusedinc _male _age i._partyid   [pw=_weight] if _data=="bsa"
	eststo rESS08_id: 		logit _refusedinc _male _age i._partyid   [pw=_weight] if _data=="ESS08" & _nation==9
		testparm i(2 3 5 6)._partyid
	eststo rTUC_vote: 		logit _refusedinc _male _age i._partyvote [pw=_weight] if _data=="TUC"
	eststo rTUC_id: 		logit _refusedinc _male _age i._partyid   [pw=_weight] if _data=="TUC"
	esttab r*, not nodepvars nonum
	estimates drop r*
END CHECKS*/

* Setting 'dont knows' for categorical variables
// For benefit level vars in BSA (for this study only)
unab benlevvars: *G
mvencode `benlevvars', mv(.d=4)
label define ub1_XG 4 "4_dont know", modify
label values `benlevvars' ub1_XG
// For MTB variables
unab mtbvars: mtb*
mvencode `mtbvars', mv(.d=2)
label define EF101 2 "2_dont know", modify

* Creating different versions for each year
unab allvars: betteroff-JSAyr
foreach var in `allvars' {
	dis "Variable is `var'"
	tab _svyyear if ~missing(`var')
	if r(r)>=2 		{
		levelsof _svyyear if ~missing(`var')
		local levels = r(levels)
		foreach level in `levels' {
			clonevar `var'_`level' = `var' if _svyyear==`level'
		/**/ }
	/**/ }
/**/ }

sort _data _uniqueid
gen uniqueid=_n
order uniqueid, first
order oth*, last
compress

