////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
// ANALYSIS PART 1
// Descriptive results re perceptions & correctness
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////


**************************************************************
* Setting the correct answers and the lists of variables
**************************************************************

do "${dodir}\2_correct_values.do"
global contvars 	"estfraud estfraud13 falseIB falseJSA fraudspend betteroff unemprate3 outofwrk2014 outofwrk2000"
global contvars 	"${contvars} outofwrk_trend unempspend JSAfamily JSAyr"
global intcontvars 	"sickdsbN uemplwkN unemprate2_2007 unemprate2_2009"		// Ones that we can compare across countries in part 1b of the analysis
global catvars  	"betteroffC saveleast savemost sickdsb socblast socbmost socbnext spenlast spenmost uemplwk unemprate1"
global catvars  	"${catvars} spennext  JSAvPen"
global benlevvars 	"car_146G mum_XG_* pen1_XG_* penc_XG_* penc_X_increntG_* ub1_XG_* ubc_XG_* ubc_X_increntG_*"
// Other beliefs (not about the benefits system)
global othcontvars	"oth_annuity oth_avgbaserate"											// Maths ability & economics
global othcontvars	"${othcontvars} oth_car100 oth_milk oth_nursery oth_stdntdebt oth_hipay100_2001  oth_ftsalary"				// Standard of living
global othcontvars	"${othcontvars} oth_house oth_deposit oth_rent oth_rentLDN oth_debt oth_toprate oth_taxtoprate1 oth_taxtoprate2"
global othcontvars	"${othcontvars} oth_chpov100_2001  oth_propr100 oth_prpen100 oth_prsch100_2001 oth_vicri100  oth_violcrim"	// Policy & crime
global othcontvars	"${othcontvars} oth_age oth_LE65 oth_U16preg oth_vote oth_paper oth_twitter oth_facebook "					// Misc
global othcontvars	"${othcontvars} oth_blasi100 oth_christian oth_muslim oth_blackasian oth_migr oth_asylum"					// Ethnicity and migration
global othcatvars	"oth_migrC oth_asylumC oth_asylumrise oth_violrise oth_crimfall oth_maths1 oth_maths2 "						// All categorical
global othcatvars	"${othvatvars} oth_coalitiondebt oth_coalitiondeficit oth_baserate "

// Defining labels that are used below
label define correctness 1 "1_Correct" 2 "2_Underestimate" 3 "3_Overestimate" 4 "4_DontKnow", modify
label define correctcat  0 "0_Incorrect" 1 "1_Correct" 9 "9_DontKnow", modify
keep if _nation==9


**************************************************************
* Generating descriptive results for continuous variables
**************************************************************

unab contvars: ${contvars} ${intcontvars} 
foreach depvar in `contvars' {
*foreach depvar in outofwrk2014 outofwrk_trend {
	* Means and medians
	eststo `depvar'_desc:	mean `depvar' [pw=_weight]
		// Getting confidence intervals for the mean is surprisingly irritating
		matrix define mean_var = e(V)
		matrix define mean_est = e(b)
		estadd scalar mean_upper = mean_est[1,1] + invnormal(0.975) * (mean_var[1,1]^0.5)	: `depvar'_desc	
		estadd scalar mean_lower = mean_est[1,1] - invnormal(0.975) * (mean_var[1,1]^0.5)	: `depvar'_desc	
	// Confidence intervals for the median requires the EPCTILE package from Stas Kolenikov - otherwise just use || _pctile `depvar' [pw=_weight], nquant(2)
	* ssc install somersd | ssc install expgen
	epctile `depvar' [pw=_weight], p(50)
		matrix define med_output = r(table)
		estadd scalar median 	= med_output[1,1] 	: `depvar'_desc	
		estadd scalar med_upper = med_output[6,1]	: `depvar'_desc	
		estadd scalar med_lower = med_output[5,1]	: `depvar'_desc			
	* Prevalence of don't knows and correct / incorrect answers
	capture drop `depvar'T
	gen 			`depvar'T = 1 if `depvar'>=${correct_`depvar'L} & `depvar'<=${correct_`depvar'H}
		replace  	`depvar'T = 2 if `depvar'<${correct_`depvar'L} 
		replace		`depvar'T = 3 if `depvar'>${correct_`depvar'H} & ~missing(`depvar')
		replace		`depvar'T = 4 if `depvar'==.d	
		label values `depvar'T correctness
		label var `depvar'T "Correctness of `var'"
		gen `depvar'Tnol = `depvar'T
	proportion `depvar'Tnol [pw=_weight]
		matrix props = e(b)'
		local problabels = e(label1)
		local prop1 = strpos(subinstr("`problabels'"," ","",.), "1")
		local prop2 = strpos(subinstr("`problabels'"," ","",.), "2")
		local prop3 = strpos(subinstr("`problabels'"," ","",.), "3")
		local prop4 = strpos(subinstr("`problabels'"," ","",.), "4")
		if `prop1'>0		estadd scalar correct 		= props[`prop1',1]*100			: `depvar'_desc
		if `prop2'>0		estadd scalar underestimate = props[`prop2',1]*100			: `depvar'_desc
		if `prop3'>0		estadd scalar overestimate	= props[`prop3',1]*100			: `depvar'_desc
		if `prop4'>0		estadd scalar dontknow 		= props[`prop4',1]*100			: `depvar'_desc
		estadd local truefigure	= "${correct_`depvar'}"			: `depvar'_desc
		estadd scalar truerange_low = ${correct_`depvar'L} 		: `depvar'_desc
		estadd scalar truerange_hi 	= ${correct_`depvar'H}		: `depvar'_desc
	drop `depvar'Tnol
	* Generating dummy var for refusals and don't knows
	capture drop `depvar'R `depvar'D
	gen `depvar'D = (`depvar'~=.d) if (~missing(`depvar') | `depvar'==.d)
	gen `depvar'R = (`depvar'~=.r) if (~missing(`depvar') | `depvar'==.r | `depvar'==.d)
/**/ }



**************************************************************
* Benefit amount variables
**************************************************************

unab benlevvars: ${benlevvars}
foreach depvar in `benlevvars' {
	eststo `depvar'_benlev: 	proportion `depvar' [pw=_weight], nolabel
/**/ }


**************************************************************
* Categorical variables (single response given)
**************************************************************

unab catvars: ${catvars} 
foreach depvar in `catvars' {
	* Looking at responses
	eststo `depvar'_prop:		proportion `depvar' [pw=_weight], nolabel
	* Looking at correctness
	capture drop `depvar'T
	egen `depvar'T = anymatch(`depvar'), values(${correct_`depvar'})
	replace `depvar'T = . if missing(`depvar') & `depvar'~=.d
	replace `depvar'T = 9 if `depvar'==.d
	label values `depvar'T correctcat
	eststo `depvar'_catT:		proportion `depvar'T [pw=_weight], nolabel
/**/ }


**************************************************************
* Categorical variables (single responses given to two linked vars) - added Dec 2016
**************************************************************

local depvar "speneither1"
* Looking at correctness only
capture drop `depvar'T
egen `depvar'T = anymatch(spenmost spennext), values(${correct_spenmost})
	replace `depvar'T = . if missing(spenmost) & spenmost~=.d
	replace `depvar'T = 9 if spenmost==.d
	label values `depvar'T correctcat
	eststo `depvar'_catT:		proportion `depvar'T [pw=_weight], nolabel

	
local depvar "speneither2"
* Looking at correctness only
capture drop `depvar'T
egen `depvar'T = anymatch(spenmost spennext), values(${correct_`depvar'})
	replace `depvar'T = . if missing(spenmost) & spenmost~=.d
	replace `depvar'T = 9 if spenmost==.d
	label values `depvar'T correctcat
	eststo `depvar'_catT:		proportion `depvar'T [pw=_weight], nolabel
	
	
local depvar "socbeither1"
* Looking at correctness only
capture drop `depvar'T
egen `depvar'T = anymatch(socbmost socbnext), values(${correct_socbmost})
	replace `depvar'T = . if missing(socbmost) & spenmost~=.d
	replace `depvar'T = 9 if socbmost==.d
	label values `depvar'T correctcat
	eststo `depvar'_catT:		proportion `depvar'T [pw=_weight], nolabel


local depvar "socbeither2"
* Looking at correctness only
capture drop `depvar'T
egen `depvar'T = anymatch(socbmost socbnext), values(${correct_`depvar'})
	replace `depvar'T = . if missing(socbmost) & spenmost~=.d
	replace `depvar'T = 9 if socbmost==.d
	label values `depvar'T correctcat
	eststo `depvar'_catT:		proportion `depvar'T [pw=_weight], nolabel

	
	
**************************************************************
* Categorical variables (multiple responses given)
**************************************************************

// SPMOST
	// Creating a variable to put correctness in
	capture drop spmostT* spmostcount
	gen spmostTscore=0 if ~missing(spmost1)
	// Checking to see if any of the 10 responses are correct
	forvalues i = 1/10 				{
		if strmatch("${correct_spmost}", "*`i'*")==1		replace spmostTscore=spmostTscore + 1 if spmost`i'==1
		eststo spmost`i'_prop: 	proportion spmost`i' [pw=_weight], nolabel
	/**/ }
	egen spmostcount = rowtotal(spmost1-spmost10) if ~missing(spmost1)
	gen spmostT = (spmostTscore>0) if ~missing(spmost1)
		replace spmostT = 2 if spmostcount-spmostTscore==0
		replace spmostT = 9 if spmost1==.d
		label define spmostT 0 "0_none correct" 1 "1_at least one correct" 2 "2_all correct" 9 "9_dk", modify
		label values spmostT spmostT
	eststo spmostT_prop: 	proportion spmostT [pw=_weight], nolabel

	
// MTB
	// Creating a variable to put correctness in
	capture drop mtbScore
	gen mtbScore=0 if ~missing(mtb1)
	replace mtbScore = 99 if mtb1==2
	// Looping over each of the 10 benefits
	forvalues i = 1/10 	{
		// Checking to see if any of the 10 responses are correct
		if strmatch("${correct_mtb}", "*`i'*")==1		replace mtbScore = mtbScore + 1 if mtb`i'==1
		if strmatch("${correct_nonmtb}", "*`i'*")==1	replace mtbScore = mtbScore + 1 if mtb`i'==0
		// Looking at correctness for ECAH of the responses in turn
		eststo mtb`i'_prop: 	proportion mtb`i' [pw=_weight], nolabel
	/**/ }
	eststo mtbScore_prop:	proportion mtbScore [pw=_weight], nolabel

// FRAUDIS
	forvalues i = 1/9 	{
		replace fraudis`i' = 2 if fraudis`i'==.d
		eststo fraudis`i'_prop: 	proportion fraudis`i' [pw=_weight], nolabel
		replace fraudis`i' = .d if fraudis`i'==2
	/**/ }
	egen fraudisnotfraud = anymatch(fraudis4 fraudis5 fraudis6) if ~missing(fraudis1), values(1)

	
	
**************************************************************
* Outputting
**************************************************************
/*
estimates clear
estread using "${workingdir}\\${filename}_estimates", id(uniqueid) 
*/
esttab *_prop *_catT *_benlev using "${dodir}\Outputs\part1_prop.csv", ///
	csv replace compress not nostar nodepvars nonum varwidth(15) modelwidth(18)
esttab *_desc using "${dodir}\Outputs\part1_desc.csv", ///
	scalars(mean mean_upper mean_lower median med_upper med_lower truefigure truerange_low truerange_hi CORRECTNESS correct underestimate overestimate dontknow) ///
	csv replace compress not nostar sfmt(%3.2f) nodepvars nonum varwidth(15) modelwidth(18)
*esttab *_desc , scalars(mean mean_upper mean_lower median med_upper med_lower truefigure truerange_low truerange_hi CORRECTNESS correct underestimate overestimate dontknow) compress not nostar sfmt(%3.2f) nodepvars nonum varwidth(15) modelwidth(18)
